DPDK patches and discussions
 help / color / mirror / Atom feed
From: Stephen Hemminger <stephen@networkplumber.org>
To: dev@dpdk.org
Cc: Stephen Hemminger <stephen@networkplumber.org>
Subject: [dpdk-dev] [PATCH v2 05/10] drivers: replace references to blacklist
Date: Mon,  8 Jun 2020 12:25:41 -0700	[thread overview]
Message-ID: <20200608192546.7160-6-stephen@networkplumber.org> (raw)
In-Reply-To: <20200608192546.7160-1-stephen@networkplumber.org>

Use the new terminolgy BLOCKED to describe when devices
are excluded from being used.

Signed-off-by: Stephen Hemminger <stephen@networkplumber.org>
---
 drivers/bus/dpaa/dpaa_bus.c        |  7 +++----
 drivers/bus/fslmc/fslmc_bus.c      |  9 ++++-----
 drivers/bus/fslmc/fslmc_vfio.c     |  8 ++++----
 drivers/bus/pci/pci_common.c       | 21 +++++++++------------
 drivers/bus/vmbus/vmbus_common.c   |  4 ++--
 drivers/crypto/virtio/virtio_pci.c |  2 +-
 drivers/net/fm10k/fm10k_ethdev.c   |  2 +-
 drivers/net/virtio/virtio_pci.c    |  2 +-
 8 files changed, 25 insertions(+), 30 deletions(-)

diff --git a/drivers/bus/dpaa/dpaa_bus.c b/drivers/bus/dpaa/dpaa_bus.c
index d53fe6083a79..ac326d96f00d 100644
--- a/drivers/bus/dpaa/dpaa_bus.c
+++ b/drivers/bus/dpaa/dpaa_bus.c
@@ -556,7 +556,7 @@ rte_dpaa_bus_probe(void)
 	struct rte_dpaa_driver *drv;
 	FILE *svr_file = NULL;
 	unsigned int svr_ver;
-	int probe_all = rte_dpaa_bus.bus.conf.scan_mode != RTE_BUS_SCAN_WHITELIST;
+	int probe_all = rte_dpaa_bus.bus.conf.scan_mode != RTE_BUS_SCAN_ALLOWLIST;
 	static int process_once;
 
 	/* If DPAA bus is not present nothing needs to be done */
@@ -610,13 +610,12 @@ rte_dpaa_bus_probe(void)
 
 			if (!drv->probe ||
 			    (dev->device.devargs &&
-			    dev->device.devargs->policy == RTE_DEV_BLACKLISTED))
+			     dev->device.devargs->policy == RTE_DEV_BLOCKED))
 				continue;
 
 			if (probe_all ||
 			    (dev->device.devargs &&
-			    dev->device.devargs->policy ==
-			    RTE_DEV_WHITELISTED)) {
+			     dev->device.devargs->policy == RTE_DEV_ALLOWED)) {
 				ret = drv->probe(drv, dev);
 				if (ret) {
 					DPAA_BUS_ERR("unable to probe:%s",
diff --git a/drivers/bus/fslmc/fslmc_bus.c b/drivers/bus/fslmc/fslmc_bus.c
index afbd82e8dbfb..49125729202e 100644
--- a/drivers/bus/fslmc/fslmc_bus.c
+++ b/drivers/bus/fslmc/fslmc_bus.c
@@ -407,7 +407,7 @@ rte_fslmc_probe(void)
 		return 0;
 	}
 
-	probe_all = rte_fslmc_bus.bus.conf.scan_mode != RTE_BUS_SCAN_WHITELIST;
+	probe_all = rte_fslmc_bus.bus.conf.scan_mode != RTE_BUS_SCAN_ALLOWLIST;
 
 	/* In case of PA, the FD addresses returned by qbman APIs are physical
 	 * addresses, which need conversion into equivalent VA address for
@@ -438,16 +438,15 @@ rte_fslmc_probe(void)
 				continue;
 
 			if (dev->device.devargs &&
-			  dev->device.devargs->policy == RTE_DEV_BLACKLISTED) {
-				DPAA2_BUS_LOG(DEBUG, "%s Blacklisted, skipping",
+			    dev->device.devargs->policy == RTE_DEV_BLOCKED) {
+				DPAA2_BUS_LOG(DEBUG, "%s Blocklisted, skipping",
 					      dev->device.name);
 				continue;
 			}
 
 			if (probe_all ||
 			   (dev->device.devargs &&
-			   dev->device.devargs->policy ==
-			   RTE_DEV_WHITELISTED)) {
+			    dev->device.devargs->policy == RTE_DEV_ALLOWED)) {
 				ret = drv->probe(drv, dev);
 				if (ret) {
 					DPAA2_BUS_ERR("Unable to probe");
diff --git a/drivers/bus/fslmc/fslmc_vfio.c b/drivers/bus/fslmc/fslmc_vfio.c
index efe2c43d372a..3634db3f65a2 100644
--- a/drivers/bus/fslmc/fslmc_vfio.c
+++ b/drivers/bus/fslmc/fslmc_vfio.c
@@ -819,8 +819,8 @@ fslmc_vfio_process_group(void)
 	TAILQ_FOREACH_SAFE(dev, &rte_fslmc_bus.device_list, next, dev_temp) {
 		if (dev->dev_type == DPAA2_MPORTAL) {
 			if (dev->device.devargs &&
-			    dev->device.devargs->policy == RTE_DEV_BLACKLISTED) {
-				DPAA2_BUS_LOG(DEBUG, "%s Blacklisted, skipping",
+			    dev->device.devargs->policy == RTE_DEV_BLOCKED) {
+				DPAA2_BUS_LOG(DEBUG, "%s Blocklisted, skipping",
 					      dev->device.name);
 				TAILQ_REMOVE(&rte_fslmc_bus.device_list,
 						dev, next);
@@ -852,8 +852,8 @@ fslmc_vfio_process_group(void)
 
 	TAILQ_FOREACH_SAFE(dev, &rte_fslmc_bus.device_list, next, dev_temp) {
 		if (dev->device.devargs &&
-		    dev->device.devargs->policy == RTE_DEV_BLACKLISTED) {
-			DPAA2_BUS_LOG(DEBUG, "%s Blacklisted, skipping",
+		    dev->device.devargs->policy == RTE_DEV_BLOCKED) {
+			DPAA2_BUS_LOG(DEBUG, "%s Blocklisted, skipping",
 				      dev->device.name);
 			TAILQ_REMOVE(&rte_fslmc_bus.device_list, dev, next);
 			continue;
diff --git a/drivers/bus/vmbus/vmbus_common.c b/drivers/bus/vmbus/vmbus_common.c
index 3adef01c95de..ceada945e7e2 100644
--- a/drivers/bus/vmbus/vmbus_common.c
+++ b/drivers/bus/vmbus/vmbus_common.c
@@ -102,7 +102,7 @@ vmbus_probe_one_driver(struct rte_vmbus_driver *dr,
 	VMBUS_LOG(INFO, "VMBUS device %s on NUMA socket %i",
 		  guid, dev->device.numa_node);
 
-	/* TODO add blacklisted */
+	/* TODO add blocklisted */
 
 	/* map resources for device */
 	ret = rte_vmbus_map_device(dev);
@@ -178,7 +178,7 @@ rte_vmbus_probe(void)
 
 		rte_uuid_unparse(dev->device_id, ubuf, sizeof(ubuf));
 
-		/* TODO: add whitelist/blacklist */
+		/* TODO: add allowlist/blocklist */
 
 		if (vmbus_probe_all_drivers(dev) < 0) {
 			VMBUS_LOG(NOTICE,
diff --git a/drivers/crypto/virtio/virtio_pci.c b/drivers/crypto/virtio/virtio_pci.c
index f490f6e28960..c79d210cc74d 100644
--- a/drivers/crypto/virtio/virtio_pci.c
+++ b/drivers/crypto/virtio/virtio_pci.c
@@ -438,7 +438,7 @@ virtio_read_caps(struct rte_pci_device *dev, struct virtio_crypto_hw *hw)
  * Return -1:
  *   if there is error mapping with VFIO/UIO.
  *   if port map error when driver type is KDRV_NONE.
- *   if whitelisted but driver type is KDRV_UNKNOWN.
+ *   if allowlisted but driver type is KDRV_UNKNOWN.
  * Return 1 if kernel driver is managing the device.
  * Return 0 on success.
  */
diff --git a/drivers/net/fm10k/fm10k_ethdev.c b/drivers/net/fm10k/fm10k_ethdev.c
index f537ab286289..dae20aafe61d 100644
--- a/drivers/net/fm10k/fm10k_ethdev.c
+++ b/drivers/net/fm10k/fm10k_ethdev.c
@@ -3115,7 +3115,7 @@ eth_fm10k_dev_init(struct rte_eth_dev *dev)
 	hw->hw_addr = (void *)pdev->mem_resource[0].addr;
 	if (hw->hw_addr == NULL) {
 		PMD_INIT_LOG(ERR, "Bad mem resource."
-			" Try to blacklist unused devices.");
+			" Try to blocklist unused devices.");
 		return -EIO;
 	}
 
diff --git a/drivers/net/virtio/virtio_pci.c b/drivers/net/virtio/virtio_pci.c
index 29a354bf76df..8ef1e1d35a75 100644
--- a/drivers/net/virtio/virtio_pci.c
+++ b/drivers/net/virtio/virtio_pci.c
@@ -682,7 +682,7 @@ virtio_read_caps(struct rte_pci_device *dev, struct virtio_hw *hw)
  * Return -1:
  *   if there is error mapping with VFIO/UIO.
  *   if port map error when driver type is KDRV_NONE.
- *   if whitelisted but driver type is KDRV_UNKNOWN.
+ *   if allowlisted but driver type is KDRV_UNKNOWN.
  * Return 1 if kernel driver is managing the device.
  * Return 0 on success.
  */
diff --git a/drivers/bus/pci/pci_common.c b/drivers/bus/pci/pci_common.c
index 245d94f59c6e..1fa247b8fa08 100644
--- a/drivers/bus/pci/pci_common.c
+++ b/drivers/bus/pci/pci_common.c
@@ -66,7 +66,7 @@ pci_name_set(struct rte_pci_device *dev)
 			dev->name, sizeof(dev->name));
 	devargs = pci_devargs_lookup(&dev->addr);
 	dev->device.devargs = devargs;
 	/* In blacklist mode, if the device is not blacklisted, no
 	 * rte_devargs exists for it.
 	 */
 	if (devargs != NULL)
@@ -132,7 +132,7 @@ rte_pci_probe_one_driver(struct rte_pci_driver *dr,
 
 	loc = &dev->addr;
 
-	/* The device is not blacklisted; Check if driver supports it */
+	/* The device is not blocklisted; Check if driver supports it */
 	if (!rte_pci_match(dr, dev))
 		/* Match of device and driver failed */
 		return 1;
@@ -141,12 +141,10 @@ rte_pci_probe_one_driver(struct rte_pci_driver *dr,
 			loc->domain, loc->bus, loc->devid, loc->function,
 			dev->device.numa_node);
 
-	/* no initialization when blacklisted, return without error */
+	/* no initialization when blocklisted, return without error */
 	if (dev->device.devargs != NULL &&
-		dev->device.devargs->policy ==
-			RTE_DEV_BLACKLISTED) {
-		RTE_LOG(INFO, EAL, "  Device is blacklisted, not"
-			" initializing\n");
+		dev->device.devargs->policy == RTE_DEV_BLOCKED) {
+		RTE_LOG(INFO, EAL, "  Device is blocked, not initializing\n");
 		return 1;
 	}
 
@@ -589,14 +587,13 @@ rte_pci_ignore_device(const struct rte_pci_addr *pci_addr)
 	struct rte_devargs *devargs = pci_devargs_lookup(pci_addr);
 
 	switch (rte_pci_bus.bus.conf.scan_mode) {
-	case RTE_BUS_SCAN_WHITELIST:
-		if (devargs && devargs->policy == RTE_DEV_WHITELISTED)
+	case RTE_BUS_SCAN_ALLOWLIST:
+		if (devargs && devargs->policy == RTE_DEV_ALLOWED)
 			return false;
 		break;
 	case RTE_BUS_SCAN_UNDEFINED:
-	case RTE_BUS_SCAN_BLACKLIST:
-		if (devargs == NULL ||
-		    devargs->policy != RTE_DEV_BLACKLISTED)
+	case RTE_BUS_SCAN_BLOCKLIST:
+		if (devargs == NULL || devargs->policy != RTE_DEV_BLOCKED)
 			return false;
 		break;
 	}
@@ -66,7 +66,7 @@ pci_name_set(struct rte_pci_device *dev)
 	devargs = pci_devargs_lookup(&dev->addr);
 	dev->device.devargs = devargs;
-	/* In blacklist mode, if the device is not blacklisted, no
+	/* In blocklist mode, if the device is not blocklisted, no
 	 * rte_devargs exists for it.
 	 */
-- 
2.26.2


  parent reply	other threads:[~2020-06-08 19:26 UTC|newest]

Thread overview: 38+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2020-06-07 17:01 [dpdk-dev] [PATCH 0/9] Rename blacklist/whitelist to blocklist/allowlist Stephen Hemminger
2020-06-07 17:01 ` [dpdk-dev] [PATCH 1/9] rte_ethdev: change comment to rte_dev_eth_mac_addr_add Stephen Hemminger
2020-06-07 17:01 ` [dpdk-dev] [PATCH 2/9] mk: replace reference to blacklist/whitelist Stephen Hemminger
2020-06-07 17:01 ` [dpdk-dev] [PATCH 3/9] check_maintainers: change variable names Stephen Hemminger
2020-06-07 17:01 ` [dpdk-dev] [PATCH 4/9] eal: replace usage of blacklist/whitelist in enum Stephen Hemminger
2020-06-07 22:48   ` Gaëtan Rivet
2020-06-07 17:01 ` [dpdk-dev] [PATCH 5/9] drivers: replace references to blacklist Stephen Hemminger
2020-06-07 17:01 ` [dpdk-dev] [PATCH 6/9] eal: replace pci-whitelist/pci-blacklist options Stephen Hemminger
2020-06-08  9:30   ` Bruce Richardson
2020-06-07 17:01 ` [dpdk-dev] [PATCH 7/9] doc: replace references to blacklist/whitelist Stephen Hemminger
2020-06-07 17:01 ` [dpdk-dev] [PATCH 8/9] app/test: use new allowlist and blocklist Stephen Hemminger
2020-06-07 17:01 ` [dpdk-dev] [PATCH 9/9] doc: add note about blacklist/whitelist changes Stephen Hemminger
2020-06-08  8:35 ` [dpdk-dev] [PATCH 0/9] Rename blacklist/whitelist to blocklist/allowlist Luca Boccassi
2020-06-08 19:25 ` [dpdk-dev] [PATCH v2 00/10] Rename blacklist/whitelist to Stephen Hemminger
2020-06-08 19:25   ` [dpdk-dev] [PATCH v2 01/10] rte_ethdev: change comment to rte_dev_eth_mac_addr_add Stephen Hemminger
2020-06-08 19:25   ` [dpdk-dev] [PATCH v2 02/10] mk: replace reference to blacklist/whitelist Stephen Hemminger
2020-06-08 19:25   ` [dpdk-dev] [PATCH v2 03/10] check_maintainers: change variable names Stephen Hemminger
2020-06-08 19:25   ` [dpdk-dev] [PATCH v2 04/10] eal: replace usage of blacklist/whitelist in enum Stephen Hemminger
2020-06-08 19:25   ` Stephen Hemminger [this message]
2020-06-08 19:25   ` [dpdk-dev] [PATCH v2 06/10] eal: replace pci-whitelist/pci-blacklist options Stephen Hemminger
2020-06-08 19:25   ` [dpdk-dev] [PATCH v2 07/10] doc: replace references to blacklist/whitelist Stephen Hemminger
2020-06-08 19:25   ` [dpdk-dev] [PATCH v2 08/10] app/test: use new allowlist and blocklist Stephen Hemminger
2020-06-08 19:25   ` [dpdk-dev] [PATCH v2 09/10] doc: add note about blacklist/whitelist changes Stephen Hemminger
2020-06-08 19:25   ` [dpdk-dev] [PATCH v2 10/10] eal: mark old macros for blacklist/whitelist as deprecated Stephen Hemminger
2020-06-09  9:37   ` [dpdk-dev] [PATCH v2 00/10] Rename blacklist/whitelist to Luca Boccassi
2020-07-15 23:02 ` [dpdk-dev] [PATCH v5 0/9] rename blacklist/whitelist to exclude/include Stephen Hemminger
2020-07-15 23:02   ` [dpdk-dev] [PATCH v5 1/9] rte_ethdev: change comment to rte_dev_eth_mac_addr_add Stephen Hemminger
2020-07-15 23:02   ` [dpdk-dev] [PATCH v5 2/9] mk: replace reference to blacklist/whitelist Stephen Hemminger
2020-07-15 23:02   ` [dpdk-dev] [PATCH v5 3/9] check_maintainers: change variable names Stephen Hemminger
2020-07-15 23:02   ` [dpdk-dev] [PATCH v5 4/9] eal: replace usage of blacklist/whitelist in enum Stephen Hemminger
2020-07-15 23:02   ` [dpdk-dev] [PATCH v5 5/9] drivers: replace references to blacklist Stephen Hemminger
2020-07-15 23:02   ` [dpdk-dev] [PATCH v5 6/9] eal: replace pci-whitelist/pci-blacklist options Stephen Hemminger
2020-07-15 23:02   ` [dpdk-dev] [PATCH v5 7/9] app/test: use new allowlist and blocklist Stephen Hemminger
2020-07-15 23:02   ` [dpdk-dev] [PATCH v5 8/9] eal: mark old macros for blacklist/whitelist as deprecated Stephen Hemminger
2020-07-15 23:02   ` [dpdk-dev] [PATCH v5 9/9] doc: replace references to blacklist/whitelist Stephen Hemminger
2020-07-15 23:49     ` Stephen Hemminger
2020-06-12  0:20 [dpdk-dev] [PATCH v2 00/10] Rename blacklsit/whitelist to block/allow list Stephen Hemminger
2020-06-12  0:20 ` [dpdk-dev] [PATCH v2 05/10] drivers: replace references to blacklist Stephen Hemminger
2020-06-12  9:33   ` Gaëtan Rivet

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20200608192546.7160-6-stephen@networkplumber.org \
    --to=stephen@networkplumber.org \
    --cc=dev@dpdk.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).